#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <avr/io.h>
#include <util/delay.h>

#include "lcd/lcd.h"
#include "twi/twi.h"

int
main()
{
  /* Initialize LCD */
  lcd_init();

  /* Turn on LCD */
  lcd_on();

  /* Turn on LCD backlight to full brightness */
  lcd_led_set(0xff);

  /* Flush test message to LCD RAM */
  lcd_clear();

  /* Allocate a new buffer for storing temperature string */
  char buf[] = "      0 deg C";
  lcd_text_buffer_t tb2 = {buf};

  int8_t temp = 0;

  twi_init();
  for (;;) {
    for (;;) {
      /* Use TWI to get a temperature reading from the on-board temperature sensor 
       * Refer to spec sheet and bens_board schematic for address info
       */
      int8_t new_temp = 0 /*???*/;

      if (new_temp == temp) {
        /* Don't refresh output if nothing changed */
        _delay_ms(10);
        continue;
      }
      temp = new_temp;
      break;
    }
  
    /* Convert temperature to a string */
    uint8_t tmp = temp > 0 ? temp : -temp;
    for (int i = 0; i < 6; ++i) {
      if (tmp == 0) {
        buf[6 - i] = ' ';
      } else {
        buf[6 - i] = (tmp % 10) + '0';
        tmp /= 10;
        if (tmp == 0 && temp < 0) {
          ++i;
          buf[6 - i] = '-';
        }
      }
    }

    /* Write string to LCD */
    lcd_flush_text(tb2);
  }
}
